## Instamatic demos

These are some demo's that show some of the functions of `instamatic`

- [Interactive data collection](data_collection.ipynb)
- [Example of grid montage acquisition](grid_montage_collection.ipynb)
- [Montage processing](montage_processing.ipynb)
- [Montage processing (SerialEM data)](https://github.com/instamatic-dev/pyserialem/demos/montage_processing_serialem.ipynb)

Use `jupyter notebook` to run these notebooks offline.
